@@ -27,9 +27,7 @@
 #include <thai/thwchar.h>
 #include <thai/thbrk.h>
 
-#ifndef HAVE_TH_BRK_FIND_BREAKS
 G_LOCK_DEFINE_STATIC (th_brk);
-#endif
 
 /*
  * tis_text is assumed to be large enough to hold the converted string,
@@ -64,9 +62,6 @@ break_thai (const char          *text,
   thchar_t *tis_text;
   int *brk_pnts;
   int cnt;
-#ifdef HAVE_TH_BRK_FIND_BREAKS
-  ThBrk* brk;
-#endif
 
   cnt = pango_utf8_strlen (text, len) + 1;
 
@@ -82,22 +77,11 @@ break_thai (const char          *text,
 
   /* find line break positions */
 
-#ifdef HAVE_TH_BRK_FIND_BREAKS
-  brk = th_brk_new(NULL);
-  len = th_brk_find_breaks(brk, tis_text, brk_pnts, cnt);
-  th_brk_delete(brk);
-#else
   G_LOCK (th_brk);
-  len = th_brk (tis_text, brk_pnts, cnt);
+  len = th_brk (tis_text, brk_pnts, len);
   G_UNLOCK (th_brk);
-#endif
   for (cnt = 0; cnt < len; cnt++)
-    if (attrs[brk_pnts[cnt]].is_char_break)
     {
-      /* Only allow additional line breaks if line-breaking is NOT
-       * prohibited. (The alternative would be to set is_char_break to
-       * TRUE as well.  NOT setting it will break invariants that any
-       * line break opportunity is also a char break opportunity. */
       attrs[brk_pnts[cnt]].is_line_break = TRUE;
       attrs[brk_pnts[cnt]].is_word_start = TRUE;
       attrs[brk_pnts[cnt]].is_word_end = TRUE;
